@@ -6,7 +6,7 @@
 #include <math.h>
 
 // Maximum number of items expected on a csv line
-#define MAX_ITEMS 48
+#define MAX_ITEMS 50
 using namespace std;
 typedef vector<PCCHAR> STR_VEC;
 
@@ -43,19 +43,22 @@ const VALS_TYPE vals[MAX_ITEMS] =
 bool col_used[MAX_ITEMS];
 #define COL_NAME 2
 #define COL_CONCURRENCY 3
-#define COL_FILE_size 5
-#define COL_DATA_CHUNK_size 6
-#define COL_PUTC 7
-#define COL_NUM_FILES 19
-#define COL_MAX_size 20
-#define COL_MIN_size 21
-#define COL_NUM_DIRS 22
-#define COL_FILE_CHUNK_size 23
-#define COL_RAN_DEL_CPU 35
-#define COL_PUTC_LATENCY 36
-#define COL_SEEKS_LATENCY 41
-#define COL_SEQ_CREATE_LATENCY 42
-#define COL_RAN_DEL_LATENCY 47
+#define COL_FILE_SIZE 5
+#define COL_DATA_CHUNK_SIZE 6
+#define COL_PUTC 9
+#define COL_PUT_BLOCK 11
+#define COL_REWRITE 13
+#define COL_GET_BLOCK 17
+#define COL_NUM_FILES 21
+#define COL_MAX_SIZE 22
+#define COL_MIN_SIZE 23
+#define COL_NUM_DIRS 24
+#define COL_FILE_CHUNK_SIZE 25
+#define COL_RAN_DEL_CPU 37
+#define COL_PUTC_LATENCY 38
+#define COL_SEEKS_LATENCY 43
+#define COL_SEQ_CREATE_LATENCY 44
+#define COL_RAN_DEL_LATENCY 49
 
 void usage()
 {
@@ -94,7 +97,7 @@ int main(int argc, char **argv)
     int j;
     for(j = COL_CONCURRENCY; j < MAX_ITEMS; j++)
     {
-      if( (j >= COL_NUM_FILES && j <= COL_FILE_CHUNK_size) || j <= COL_DATA_CHUNK_size )
+      if( (j >= COL_NUM_FILES && j <= COL_FILE_CHUNK_SIZE) || j <= COL_DATA_CHUNK_SIZE )
       {
         props[i][j] = "class=\"size\" bgcolor=\"#FFFFFF\"";
       }
@@ -113,24 +116,24 @@ int main(int argc, char **argv)
     print_item(i, COL_NAME, "rowspan=\"2\"");
     if(col_used[COL_CONCURRENCY] == true)
       print_item(i, COL_CONCURRENCY);
-    print_item(i, COL_FILE_size); // file_size
-    if(col_used[COL_DATA_CHUNK_size] == true)
-      print_item(i, COL_DATA_CHUNK_size);
+    print_item(i, COL_FILE_SIZE); // file_size
+    if(col_used[COL_DATA_CHUNK_SIZE] == true)
+      print_item(i, COL_DATA_CHUNK_SIZE);
     print_a_line(i, COL_PUTC, COL_NUM_FILES);
-    if(col_used[COL_MAX_size])
-      print_item(i, COL_MAX_size);
-    if(col_used[COL_MIN_size])
-      print_item(i, COL_MIN_size);
+    if(col_used[COL_MAX_SIZE])
+      print_item(i, COL_MAX_SIZE);
+    if(col_used[COL_MIN_SIZE])
+      print_item(i, COL_MIN_SIZE);
     if(col_used[COL_NUM_DIRS])
       print_item(i, COL_NUM_DIRS);
-    if(col_used[COL_FILE_CHUNK_size])
-      print_item(i, COL_FILE_CHUNK_size);
-    print_a_line(i, COL_FILE_CHUNK_size + 1, COL_RAN_DEL_CPU);
+    if(col_used[COL_FILE_CHUNK_SIZE])
+      print_item(i, COL_FILE_CHUNK_SIZE);
+    print_a_line(i, COL_FILE_CHUNK_SIZE + 1, COL_RAN_DEL_CPU);
     printf("</tr>\n");
 // Now print the latency line
     printf("<tr>");
     int lat_width = 1;
-    if(col_used[COL_DATA_CHUNK_size] == true)
+    if(col_used[COL_DATA_CHUNK_SIZE] == true)
       lat_width++;
     if(col_used[COL_CONCURRENCY] == true)
       lat_width++;
@@ -366,18 +369,18 @@ void heading(const char * const head);
 int header()
 {
   int vers_width = 2;
-  if(col_used[COL_DATA_CHUNK_size] == true)
+  if(col_used[COL_DATA_CHUNK_SIZE] == true)
     vers_width++;
   if(col_used[COL_CONCURRENCY] == true)
     vers_width++;
   int mid_width = 1;
-  if(col_used[COL_MAX_size])
+  if(col_used[COL_MAX_SIZE])
     mid_width++;
-  if(col_used[COL_MIN_size])
+  if(col_used[COL_MIN_SIZE])
     mid_width++;
   if(col_used[COL_NUM_DIRS])
     mid_width++;
-  if(col_used[COL_FILE_CHUNK_size])
+  if(col_used[COL_FILE_CHUNK_SIZE])
     mid_width++;
   printf("<!DOCTYPE html PUBLIC \"-//W3C//Dtd XHTML 1.0 Strict//EN\" \"http://www.w3.org/tr/xhtml1/Dtd/xhtml1-strict.dtd\">"
 "<html xmlns=\"http://www.w3.org/1999/xhtml\">"
@@ -406,18 +409,18 @@ int header()
   else
     printf("<td></td>");
   printf("<td>Size</td>");
-  if(col_used[COL_DATA_CHUNK_size] == true)
+  if(col_used[COL_DATA_CHUNK_SIZE] == true)
     printf("<td>Chunk Size</td>");
   heading("Per Char"); heading("Block"); heading("Rewrite");
   heading("Per Char"); heading("Block");
   printf("<td>Num Files</td>");
-  if(col_used[COL_MAX_size])
+  if(col_used[COL_MAX_SIZE])
     printf("<td>Max Size</td>");
-  if(col_used[COL_MIN_size])
+  if(col_used[COL_MIN_SIZE])
     printf("<td>Min Size</td>");
   if(col_used[COL_NUM_DIRS])
     printf("<td>Num Dirs</td>");
-  if(col_used[COL_FILE_CHUNK_size])
+  if(col_used[COL_FILE_CHUNK_SIZE])
     printf("<td>Chunk Size</td>");
   heading("Create"); heading("Read"); heading("Delete");
   heading("Create"); heading("Read"); heading("Delete");
@@ -430,7 +433,7 @@ int header()
                       "<td class=\"ksec\"><font size=-2>%% CPU</font></td>";
   for(i = 0; i < 5; i++)
   {
-    printf(ksec_form, "K");
+    printf(ksec_form, "M");
   }
   printf(ksec_form, "");
   printf("<td colspan=\"%d\"></td>", mid_width);
@@ -484,8 +487,20 @@ void read_in(CPCCHAR buf)
 void print_item(int num, int item, CPCCHAR extra)
 {
   PCCHAR line_data;
+  char buf[1024];
   if(int(data[num].size()) > item)
+  {
     line_data = data[num][item];
+    switch(item)
+    {
+    case COL_PUT_BLOCK:
+    case COL_REWRITE:
+    case COL_GET_BLOCK:
+      int tmp = (atoi(line_data) + 512) / 1024;
+      snprintf(buf, sizeof(buf), "%d", tmp);
+      line_data = buf;
+    }
+  }
   else
     line_data = "";
   printf("<td");
